# Generated by Django 5.0.3 on 2024-03-19 08:08

import uuid

import django.utils.timezone
from django.db import migrations, models

import remotejwt_user.models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="User",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("password", models.CharField(max_length=128, verbose_name="password")),
                (
                    "last_login",
                    models.DateTimeField(
                        blank=True, null=True, verbose_name="last login"
                    ),
                ),
                (
                    "is_superuser",
                    models.BooleanField(
                        default=False,
                        help_text="Designates that this user has all permissions without explicitly assigning them.",
                        verbose_name="superuser status",
                    ),
                ),
                (
                    "is_staff",
                    models.BooleanField(
                        default=False,
                        help_text="Designates whether the user can log into this admin site.",
                        verbose_name="staff status",
                    ),
                ),
                (
                    "is_active",
                    models.BooleanField(
                        default=True,
                        help_text="Designates whether this user should be treated as active. Unselect this instead of deleting accounts.",
                        verbose_name="active",
                    ),
                ),
                (
                    "date_joined",
                    models.DateTimeField(
                        default=django.utils.timezone.now, verbose_name="date joined"
                    ),
                ),
                (
                    "first_name",
                    models.CharField(
                        blank=True, max_length=150, verbose_name="first name"
                    ),
                ),
                (
                    "last_name",
                    models.CharField(
                        blank=True, max_length=150, verbose_name="last name"
                    ),
                ),
                ("location", models.TextField(blank=True, null=True)),
                ("phone", models.CharField(blank=True, max_length=15, null=True)),
                (
                    "email",
                    models.EmailField(
                        error_messages={"unique": "This email already exists."},
                        help_text="Please Enter valid Email Address",
                        max_length=254,
                        verbose_name="email address",
                    ),
                ),
                (
                    "modified_date",
                    models.DateTimeField(auto_now=True, verbose_name="modified date"),
                ),
                (
                    "creation_date",
                    models.DateTimeField(
                        auto_now_add=True, verbose_name="creation date"
                    ),
                ),
                ("jwt_secret", models.UUIDField(default=uuid.uuid4, editable=False)),
                # (
                #     "groups",
                #     models.ManyToManyField(
                #         blank=True,
                #         help_text="The groups this user belongs to. A user will get all permissions granted to each of their groups.",
                #         related_name="user_set",
                #         related_query_name="user",
                #         to="auth.group",
                #         verbose_name="groups",
                #     ),
                # ),
                # (
                #     "user_permissions",
                #     models.ManyToManyField(
                #         blank=True,
                #         help_text="Specific permissions for this user.",
                #         related_name="user_set",
                #         related_query_name="user",
                #         to="auth.permission",
                #         verbose_name="user permissions",
                #     ),
                # ),
            ],
            options={
                "verbose_name": "user",
                "verbose_name_plural": "users",
                "db_table": "user",
                "abstract": False,
                "swappable": "AUTH_USER_MODEL",
            },
            managers=[
                ("objects", remotejwt_user.models.UserManager()),
            ],
        ),
        migrations.AddConstraint(
            model_name="user",
            constraint=models.UniqueConstraint(
                fields=("email",), name="user_email_type_unique"
            ),
        ),
    ]
